<?php
/**
 *
 * Slideshow for Header extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2018 Picaron
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace Picaron\SlideWeUni\event;

/**
 * Event listener
 */
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
    /** @var \phpbb\user */
    protected $user;

    /** @var \phpbb\template\template */
    protected $template;

    /** @var \phpbb\db\driver\driver_interface */
    protected $db;

    /** @var \phpbb\auth\auth */
    protected $auth;

    /** @var \phpbb\request\request */
    protected $request;

    /** @var string */
    protected $phpbb_root_path;

    /** @var string */
    protected $phpEx;

    /**
    * Constructor
    *
    * @param \phpbb\user                        $user
    * @param \phpbb\template\template           $template
    * @param \phpbb\db\driver\driver_interface  $db
    * @param \phpbb\auth\auth                   $auth
    * @param \phpbb\request\request             $request
    * @param string                             $phpbb_root_path
    * @param string                             $phpEx
    *
    */
    public function __construct(\phpbb\user $user, \phpbb\template\template $template, \phpbb\db\driver\driver_interface $db, \phpbb\auth\auth $auth, \phpbb\request\request $request, $phpbb_root_path, $phpEx)
    {
        $this->user                 = $user;
        $this->template             = $template;
        $this->db                   = $db;
        $this->auth                 = $auth;
        $this->request              = $request;
        $this->phpbb_root_path      = $phpbb_root_path;
        $this->phpEx                = $phpEx;
    }

    /**
     * Assign functions defined in this class to event listeners in the core
     *
     * @return array
     * @static
     * @access public
     */
    static public function getSubscribedEvents()
    {
        return array(
            'core.page_header'                     => 'page_header',
            'core.build_config_template'           => 'build_config_template',
        );
    }

    /**
     * Set SlideShow template data - Execute code and/or overwrite page_header()
     *
     * @return null
     * @access public
     */
    public function page_header()
    {
        global $config;

        if ($config['slide_weuni_active'])
        {
            if ($config['slide_weuni_aleatory'])
            {
                // Random YES
                // Take slide_weuni_cant_img ramdon number
                $valores = array();
                $x = 0;
                $num = $config['slide_weuni_cant_img'];
                while ($x<$num) {
                    $num_aleatorio = rand(1,$num);
                    if (!in_array($num_aleatorio,$valores)) {
                        array_push($valores,$num_aleatorio);
                        $x++;
                    }
                }
            } else {
                // Random NO
                for($i=1;$i<=$config['slide_weuni_cant_img'];$i++)
                {
                    $valores[$i] = $i;
                }
            }

            // By default all variables are false/null
            $img_on = $url_on = $img_in_url = $img_img = $url_img = $url_dest = array();
            for($i=1;$i<=$config['slide_weuni_cant_img'];$i++)
            {
                $img_on[$i] = $url_on[$i] = $img_in_url[$i] = false;
                $img_img[$i] = $url_img[$i] = '';
                $url_dest[$i] = '_parent';
            }

            // Asign first only vars with any image
            $baner = 1;
            $imagenes = false;
            foreach ($valores as $key)
            {
                if($config['slide_weuni_img'.$key] != '')
                {
                    $img_on[$baner] = true;
                    $imagenes = true;
                    $img_img[$baner] = $config['slide_weuni_img'.$key];
                    $img_in_url[$baner] = (substr($config['slide_weuni_img'.$key], 0, 4) == "http") ? true : false;
                    if($config['slide_weuni_url'.$key] != '')
                    {
                        $url_on[$baner] = true;
                        $url_img[$baner] = $config['slide_weuni_url'.$key];

                        $pos = strpos($config['slide_weuni_url'.$key], $config['server_name']);
                        if ($pos === false) {
                            $url_dest[$baner] = '_blank';
                        }
                    }
                    $baner ++;
                }
            }

            // Any image to Show in Slide ??
            if($imagenes == false) { $passok = false; } else { $passok = ($config['slide_weuni_active']) ? true : false; }

            // Add the items to the template
            for($i=1;$i<=$config['slide_weuni_cant_img'];$i++)
            {
                $this->template->assign_block_vars('slidec', array(
                    'S_SLIDE_WEUNI_IMG_ON'  =>  $img_on[$i],
                    'S_SLIDE_WEUNI_I'       =>  $i-1,
                ));

                $this->template->assign_block_vars('slidei', array(
                    'S_SLIDE_WEUNI_IMG_ON'      =>  $img_on[$i],
                    'S_IMAGE_IN_URL'            =>  $img_in_url[$i],
                    'S_SLIDE_WEUNI_IMG_IMG'     =>  $img_img[$i],
                    'S_SLIDE_WEUNI_URL_ON'      =>  $url_on[$i],
                    'S_SLIDE_WEUNI_URL_IMG'     =>  $url_img[$i],
                    'S_SLIDE_WEUNI_URL_DEST'    =>  $url_dest[$i],
                    'S_SLIDE_WEUNI_I'           =>  $i-1,
                ));
            }

            // Asign vars to Template
            $this->template->assign_vars(array(
                'S_SLIDE_WEUNI_ACTIVE'      => $passok,
                'S_SLIDE_WEUNI_DELAY'       => $config['slide_weuni_delay'],
                'S_SLIDE_WEUNI_TITLE'       => ($config['slide_weuni_title'] == 1) ?  true : false,
                'S_SLIDE_WEUNI_SEARCH'      => ($config['slide_weuni_search'] == 1) ?  true : false,
                'S_EFFECT'                  => ($config['slide_weuni_effect'] == 1) ? null : ' carousel-fade',
                'S_SLIDE_WEUNI_COLOR_TIT_F' => $config['slide_weuni_color_tit_f'],
                'S_SLIDE_WEUNI_COLOR_TIT_B' => $config['slide_weuni_color_tit_b'],
                'S_SLIDE_WEUNI_INTER'       => ($config['slide_weuni_inter'] == 1) ?  true : false,
                'S_SLIDE_WEUNI_CONTROLS'    => ($config['slide_weuni_controls'] == 1) ?  true : false,
            ));

        }
    }

    /**
    * ACP fonction : Select effect for Slideshow for Header
    *
    * @param object $event The event object
    *
    * @return null
    * @access public
    */
    public function build_config_template($event)
    {
        if ($event['key'] == 'slide_weuni_effect')
        {
            global $config;
            $event['tpl'] = '<select id="slide_weuni_effect" name="config[slide_weuni_effect]"><option value="1"' . (($config['slide_weuni_effect'] == 1) ? ' selected="selected"' : '') . '>' . $this->user->lang['L_SLIDE'] . '</option><option value="2"' . (($config['slide_weuni_effect'] == 2) ? ' selected="selected"' : '') . '>' . $this->user->lang['L_FADE'] . '</option></select>';
        }
    }
}
?>