<?php
/**
 *
 * Slideshow for Header extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2018 Picaron
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace Picaron\SlideWeUni;

/**
* Extension class Slideshow for Header for custom enable/disable/purge actions
*/
class ext extends \phpbb\extension\base
{
    /**
    * Check whether or not the extension can be enabled.
    * @return bool
    * @access public
    */
    public function is_enableable()
    {
        global $phpbb_root_path;

        $lang = $this->container->get('language');
        $lang->add_lang('info_acp_slideweuni', 'Picaron/SlideWeUni');

        // Requires phpBB 3.2.3 or newer.
        $config = $this->container->get('config');
        $is_enableable = phpbb_version_compare($config['version'], '3.2.3', '>=');

        // Display a custom warning message if requirement fails.
        if (!$is_enableable)
        {
            // Suppress the error in case of CLI usage
            @trigger_error($lang->lang('SLIDE_WEUNI_INSTALL_ERROR'), E_USER_WARNING);
            return $is_enableable;
        }

        // Verify if the we_universal style is installed.
        if (file_exists($phpbb_root_path.'styles/we_universal/style.cfg'))
        {
            // Read configuration
            $cfg = parse_cfg_file($phpbb_root_path.'styles/we_universal/style.cfg');

            if (isset($cfg['phpbb_version']))
            {
                // Requires the PHPBB version indicated in the we_universal style.
                $is_ver_phpbb = phpbb_version_compare($config['version'], $cfg['phpbb_version'], '>=');

                // Display a custom warning message if requirement fails.
                if (!$is_ver_phpbb)
                {
                    // Suppress the error in case of CLI usage
                    @trigger_error(sprintf($lang->lang('SLIDE_WEUNI_INSTALL_PHP_ERROR', $config['version'], $cfg['phpbb_version'])), E_USER_WARNING);
                    return $is_ver_phpbb;
                }

                // Requires we_universal 2.5.6 or newer.
                $is_ver_we = phpbb_version_compare($cfg['style_version'], '2.5.6', '>=');

                // Display a custom warning message if requirement fails.
                if (!$is_ver_we)
                {
                    // Suppress the error in case of CLI usage
                    @trigger_error(sprintf($lang->lang('SLIDE_WEUNI_INSTALL_WE_ERROR', $cfg['style_version'], '2.5.6')), E_USER_WARNING);
                    return $is_ver_we;
                }
            }
        }
        return $is_enableable;
    }
}
?>